@@ -13,6 +13,8 @@ steady.band  <- function (y, time=0, func, parms=NULL, nspec=NULL, bandup=nspec,
   if (is.null(banddown))
     stop ("cannot run steady.band: banddown is not specified")
 
-  stode(y,time,func,parms=parms,
+  out <- stode(y,time,func,parms=parms,
         bandup=bandup,banddown=banddown,jactype="bandint",...) 
+  class(out) <- c("steady","rootSolve","list")    # a steady-state 
+  return(out)
 }
